@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -194,10 +194,11 @@ static gchar *get_user_string		(const gchar	*action,
 ActionType action_get_type(const gchar *action_str)
 {
 	const gchar *p;
+	gboolean in_filtering_action = FALSE;
 	ActionType action_type = ACTION_NONE;
 
-	g_return_val_if_fail(action_str,  ACTION_ERROR);
-	g_return_val_if_fail(*action_str, ACTION_ERROR);
+	cm_return_val_if_fail(action_str,  ACTION_ERROR);
+	cm_return_val_if_fail(*action_str, ACTION_ERROR);
 
 	p = action_str;
 
@@ -216,55 +217,60 @@ ActionType action_get_type(const gchar *action_str)
 		return ACTION_ERROR;
 
 	while (*p && action_type != ACTION_ERROR) {
-		if (p[0] == '%' && p[1]) {
-			switch (p[1]) {
-			case 'a':
-				/* CLAWS: filtering action is a mutually exclusive
-				 * action. we can enable others if needed later. we
-				 * add ACTION_SINGLE | ACTION_MULTIPLE so it will
-				 * only be executed from the main window toolbar */
-				if (p[2] == 's')  /* source messages */
-					action_type = ACTION_FILTERING_ACTION 
-						    | ACTION_SINGLE 
-						    | ACTION_MULTIPLE;
-				break;
-			case 'f':
-				action_type |= ACTION_SINGLE;
-				break;
-			case 'F':
-				action_type |= ACTION_MULTIPLE;
-				break;
-			case 'p':
-				action_type |= ACTION_SINGLE;
-				break;
-			case 's':
-				action_type |= ACTION_SELECTION_STR;
-				break;
-			case 'u':
-				action_type |= ACTION_USER_STR;
-				break;
-			case 'h':
-				action_type |= ACTION_USER_HIDDEN_STR;
-				break;
-			case '%':
-				/* literal '%' */
-				break;
-			default:
-				action_type = ACTION_ERROR;
-				break;
+		if (!in_filtering_action) {
+			if (p[0] == '%' && p[1]) {
+				switch (p[1]) {
+				case 'a':
+					/* CLAWS: filtering action is a mutually exclusive
+					* action. we can enable others if needed later. we
+					* add ACTION_SINGLE | ACTION_MULTIPLE so it will
+					* only be executed from the main window toolbar */
+					if (p[2] == 's')  /* source messages */
+						action_type = ACTION_FILTERING_ACTION 
+								| ACTION_SINGLE 
+								| ACTION_MULTIPLE;
+					in_filtering_action = TRUE;
+					break;
+				case 'f':
+					action_type |= ACTION_SINGLE;
+					break;
+				case 'F':
+					action_type |= ACTION_MULTIPLE;
+					break;
+				case 'p':
+					action_type |= ACTION_SINGLE;
+					break;
+				case 's':
+					action_type |= ACTION_SELECTION_STR;
+					break;
+				case 'u':
+					action_type |= ACTION_USER_STR;
+					break;
+				case 'h':
+					action_type |= ACTION_USER_HIDDEN_STR;
+					break;
+				case '%':
+					/* literal '%' */
+					break;
+				default:
+					action_type = ACTION_ERROR;
+					break;
+				}
+				p++;
+			} else if (p[0] == '|') {
+				if (p[1] == '\0')
+					action_type |= ACTION_PIPE_OUT;
+			} else if (p[0] == '>') {
+				if (p[1] == '\0')
+					action_type |= ACTION_INSERT;
+			} else if (p[0] == '&') {
+				if (p[1] == '\0')
+					action_type |= ACTION_ASYNC;
+			} else if (p[0] == '}') {
+				in_filtering_action = FALSE;
 			}
-			p++;
-		} else if (p[0] == '|') {
-			if (p[1] == '\0')
-				action_type |= ACTION_PIPE_OUT;
-		} else if (p[0] == '>') {
-			if (p[1] == '\0')
-				action_type |= ACTION_INSERT;
-		} else if (p[0] == '&') {
-			if (p[1] == '\0')
-				action_type |= ACTION_ASYNC;
 		}
-		p++;
+			p++;
 	}
 
 	return action_type;
@@ -365,7 +371,7 @@ static gboolean parse_append_filename(GString *cmd, MsgInfo *msginfo)
 	gchar *p, *q;
 	gchar escape_ch[] = "\\ ";
 
-	g_return_val_if_fail(msginfo, FALSE);
+	cm_return_val_if_fail(msginfo, FALSE);
 
 	filename = procmsg_get_message_file(msginfo);
 
@@ -570,12 +576,12 @@ static void compose_actions_execute(Compose *compose, guint action_nb, GtkWidget
 	gchar *buf, *action;
 	ActionType action_type;
 
-	g_return_if_fail(action_nb < g_slist_length(prefs_common.actions_list));
+	cm_return_if_fail(action_nb < g_slist_length(prefs_common.actions_list));
 
 	buf = (gchar *)g_slist_nth_data(prefs_common.actions_list, action_nb);
-	g_return_if_fail(buf != NULL);
+	cm_return_if_fail(buf != NULL);
 	action = strstr(buf, ": ");
-	g_return_if_fail(action != NULL);
+	cm_return_if_fail(action != NULL);
 
 	/* Point to the beginning of the command-line */
 	action += 2;
@@ -638,12 +644,12 @@ static void message_actions_execute(MessageView *msgview, guint action_nb,
 	guint body_pos = 0;
 	ActionType action_type;
 	
-	g_return_if_fail(action_nb < g_slist_length(prefs_common.actions_list));
+	cm_return_if_fail(action_nb < g_slist_length(prefs_common.actions_list));
 
 	buf = (gchar *)g_slist_nth_data(prefs_common.actions_list, action_nb);
 
-	g_return_if_fail(buf);
-	g_return_if_fail((action = strstr(buf, ": ")));
+	cm_return_if_fail(buf);
+	cm_return_if_fail((action = strstr(buf, ": ")));
 
 	/* Point to the beginning of the command-line */
 	action += 2;
@@ -751,7 +757,7 @@ static gboolean execute_actions(gchar *action, GSList *msg_list,
 	GtkTextIter start_iter, end_iter;
 	gboolean is_selection = FALSE;
 
-	g_return_val_if_fail(action && *action, FALSE);
+	cm_return_val_if_fail(action && *action, FALSE);
 
 	action_type = action_get_type(action);
 
