@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2007 Match Grun and the Claws Mail team
+ * Copyright (C) 2002-2009 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ void addrclip_clear( AddressClipboard *clipBoard ) {
 	GList *node;
 	AddrSelectItem *item;
 
-	g_return_if_fail( clipBoard != NULL );
+	cm_return_if_fail( clipBoard != NULL );
 	node = clipBoard->objectList;
 	while( node ) {
 		item = node->data;
@@ -92,7 +92,7 @@ void addrclip_clear( AddressClipboard *clipBoard ) {
 * Free up a clipboard.
 */
 void addrclip_free( AddressClipboard *clipBoard ) {
-	g_return_if_fail( clipBoard != NULL );
+	cm_return_if_fail( clipBoard != NULL );
 
 	addrclip_clear( clipBoard );
 	clipBoard->cutFlag = FALSE;
@@ -104,8 +104,8 @@ void addrclip_free( AddressClipboard *clipBoard ) {
 void addrclip_set_index(
 	AddressClipboard *clipBoard, AddressIndex *addrIndex )
 {
-	g_return_if_fail( clipBoard != NULL );
-	g_return_if_fail( addrIndex != NULL );
+	cm_return_if_fail( clipBoard != NULL );
+	cm_return_if_fail( addrIndex != NULL );
 	clipBoard->addressIndex = addrIndex;
 }
 
@@ -131,8 +131,8 @@ gboolean addrclip_is_empty( AddressClipboard *clipBoard ) {
 void addrclip_add( AddressClipboard *clipBoard, AddrSelectList *asl ) {
 	GList *node;
 
-	g_return_if_fail( clipBoard != NULL );
-	g_return_if_fail( asl != NULL );
+	cm_return_if_fail( clipBoard != NULL );
+	cm_return_if_fail( asl != NULL );
 	node = asl->listSelect;
 	while( node ) {
 		AddrSelectItem *item, *itemCopy;
@@ -155,7 +155,7 @@ void addrclip_list_show( AddressClipboard *clipBoard, FILE *stream ) {
 	AddrItemObject *aio;
 	AddressCache *cache;
 
-	g_return_if_fail( clipBoard != NULL );
+	cm_return_if_fail( clipBoard != NULL );
 	node = clipBoard->objectList;
 	while( node != NULL ) {
 		AddrSelectItem *item;
@@ -398,8 +398,8 @@ static gboolean addrclip_is_subfolder_of(ItemFolder *is_parent, ItemFolder *is_c
 	ItemFolder *folder;
 	AddrItemObject *obj;
 
-	g_return_val_if_fail(is_parent != NULL, FALSE);
-	g_return_val_if_fail(is_child != NULL, FALSE);
+	cm_return_val_if_fail(is_parent != NULL, FALSE);
+	cm_return_val_if_fail(is_child != NULL, FALSE);
 
 	if (is_parent == is_child)
 		return TRUE;
@@ -631,7 +631,7 @@ GList *addrclip_paste_copy(
 	GList *itemList;
 	GList *folderGroup;
 
-	g_return_val_if_fail( clipBoard != NULL, NULL );
+	cm_return_val_if_fail( clipBoard != NULL, NULL );
 
 	cache = book->addressCache;
 	if( folder == NULL ) folder = cache->rootFolder;
@@ -727,7 +727,7 @@ GList *addrclip_paste_cut(
 	GList *itemList;
 	GList *folderGroup;
 
-	g_return_val_if_fail( clipBoard != NULL, NULL );
+	cm_return_val_if_fail( clipBoard != NULL, NULL );
 
 	cache = book->addressCache;
 	if( folder == NULL ) folder = cache->rootFolder;
@@ -751,112 +751,6 @@ GList *addrclip_paste_cut(
 
 	return folderGroup;
 }
-
-/*
- * ============================================================================
- * Paste address only.
- * ============================================================================
- */
-
-/*
- * Copy email addresses from specified list.
- * Enter: cache      Address cache to paste into.
- *        target     Person to receive email addresses.
- *        listEMail  List of email addresses.
- * Return: Number of addresses added.
- */
-static gint addrclip_person_add_email(
-	AddressCache *cache, ItemPerson *target, GList *listEMail )
-{
-	gint cnt;
-	GList *node;
-
-	/* Copy email addresses */
-	cnt = 0;
-	node = listEMail;
-	while( node ) {
-		ItemEMail *email, *newEMail;
-
-		email = node->data;
-		newEMail = addritem_copy_item_email( email );
-		addrcache_id_email( cache, newEMail );
-		addrcache_person_add_email( cache, target, newEMail );
-		node = g_list_next( node );
-		cnt++;
-	}
-	return cnt;
-}
-
-/*
-* Paste (copy) E-Mail addresses from clipboard into specified person.
-* Enter: aio     Address item to copy from.
-*        cache   Target address cache.
-*        person  Target person where data is pasted.
-* Return: Number of EMail records added.
-*/
-static gint addrclip_copy_email_to_person(
-	AddrItemObject *aio, AddressCache *cache, ItemPerson *person )
-{
-	gint cnt;
-	GList *listEMail;
-
-	cnt = 0;
-
-	if( ADDRITEM_TYPE(aio) == ITEMTYPE_PERSON ) {
-		ItemPerson *fromPerson;
-
-		fromPerson = ( ItemPerson * ) aio;
-		listEMail = fromPerson->listEMail;
-		cnt += addrclip_person_add_email(
-			cache, person, listEMail );
-	}
-	else if( ADDRITEM_TYPE(aio) == ITEMTYPE_EMAIL ) {
-		ItemEMail *email, *newEMail;
-
-		email = ( ItemEMail * ) aio;
-		newEMail = addritem_copy_item_email( email );
-		addrcache_id_email( cache, newEMail );
-		addrcache_person_add_email( cache, person, newEMail );
-		cnt++;
-	}
-	else if( ADDRITEM_TYPE(aio) == ITEMTYPE_GROUP ) {
-		ItemGroup *group;
-
-		group = ( ItemGroup * ) aio;
-		listEMail = group->listEMail;
-		cnt += addrclip_person_add_email(
-			cache, person, listEMail );
-	}
-	else if( ADDRITEM_TYPE(aio) == ITEMTYPE_FOLDER ) {
-		ItemFolder *folder;
-		AddrItemObject *item;
-		GList *node;
-
-		folder = ( ItemFolder * ) aio;
-		node = folder->listPerson;
-		while( node ) {
-			item = node->data;
-			node = g_list_next( node );
-			cnt += addrclip_copy_email_to_person( item, cache, person );
-		}
-
-		node = folder->listGroup;
-		while( node ) {
-			item = node->data;
-			node = g_list_next( node );
-			cnt += addrclip_copy_email_to_person( item, cache, person );
-		}
-
-		node = folder->listFolder;
-		while( node ) {
-			item = node->data;
-			node = g_list_next( node );
-			cnt += addrclip_copy_email_to_person( item, cache, person );
-		}
-	}
-	return cnt;
-}
-
 /*
 * End of Source.
 */
