@@ -1,5 +1,5 @@
 /* Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2007 Holger Berndt <hb@claws-mail.org> 
+ * Copyright (C) 2007-2009 Holger Berndt <hb@claws-mail.org> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -177,7 +177,7 @@ static void destroy_addr_hash_val(gpointer value)
 
 	for(walk = list; walk; walk = walk->next) {
 		AddrDupListEntry *entry = (AddrDupListEntry*) walk->data;
-		if(entry->book_path)
+		if(entry && entry->book_path)
 			g_free(entry->book_path);
 		if(entry)
 			g_free(entry);
@@ -767,7 +767,7 @@ static void cb_edit_btn_clicked(GtkButton *button, gpointer data)
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(detail_view));
 	selected = gtk_tree_selection_get_selected_rows(selection,&model);
-	g_return_if_fail(selected);
+	cm_return_if_fail(selected);
 
 	/* we are guaranteed to have exactly one row selected */
 	gtk_tree_view_row_activated(GTK_TREE_VIEW(detail_view),(GtkTreePath*)selected->data,
@@ -843,10 +843,11 @@ gboolean addrduplicates_delete_item_person(ItemPerson *item, AddressDataSource *
 {
 	AddressBookFile *abf;
 	AddressInterface *iface;
-
+	if (!ds)
+		return FALSE;
 	/* Test for read only */
 	iface = ds->interface;
-	if( iface->readOnly ) {
+	if( iface && iface->readOnly ) {
 		alertpanel( _("Delete address"),
 		            _("This address data is readonly and cannot be deleted."),
 		            GTK_STOCK_CLOSE, NULL, NULL );
