@@ -45,6 +45,9 @@
 #endif
 
 #ifdef G_OS_WIN32
+
+#define fsync _commit
+
 #if GLIB_CHECK_VERSION (2, 13, 2)
 #define pipe(phandles)  _pipe (phandles, 4096, _O_BINARY)
 #endif
@@ -419,6 +422,7 @@ const gchar *get_tmp_dir		(void);
 const gchar *get_locale_dir		(void);
 gchar *get_tmp_file			(void);
 const gchar *get_domain_name		(void);
+const gchar *get_desktop_file(void);
 #ifdef G_OS_WIN32
 const gchar *get_themes_dir             (void);
 const gchar *get_cert_file		(void);
