@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2008 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2010 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -61,6 +61,8 @@ static gboolean about_textview_motion_notify(GtkWidget *widget,
 static gboolean about_textview_leave_notify(GtkWidget *widget,
 					GdkEventCrossing *event,
 					GtkWidget *textview);
+static void about_size_allocate_cb(GtkWidget *widget,
+				   	GtkAllocation *allocation);
 static void about_textview_uri_update(GtkWidget *textview, gint x, gint y);
 
 static GtkWidget *link_popupmenu;
@@ -141,7 +143,7 @@ static GtkWidget *about_create_child_page_info(void)
 				NULL);
 #ifdef GENERIC_UMPC
 	gtk_text_buffer_insert(buffer, &iter, _(
-				"\n\nCopyright (C) 1999-2008\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
+				"\n\nCopyright (C) 1999-2010\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
 				"and the Claws Mail team"), -1);
 #endif
 	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (_("\n\nSystem Information\n")), -1,
@@ -425,16 +427,6 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert(buffer, &iter, 
 		(gchar *)Q_("GnuTLS|adds support for encrypted connections to servers\n"), -1);
 
-#if GTK_CHECK_VERSION(2,10,0) && !defined(USE_GNOMEPRINT)
-	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
-#else
-	gtk_text_buffer_insert_pixbuf(buffer, &iter, inactive_pixbuf);
-#endif
-	gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, (" GTK+ >= 2.10.0 "), -1,
-						 "bold", NULL);
-	gtk_text_buffer_insert(buffer, &iter, 
-		(gchar *)Q_("GTK+ >= 2.10.0|adds support for a complete print dialog\n"), -1);
-
 #if INET6
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
 #else
@@ -486,6 +478,7 @@ static GtkWidget *about_create_child_page_features(void)
 	gtk_text_buffer_insert(buffer, &iter, 
 		(gchar *)Q_("libetpan|adds support for IMAP and NNTP servers\n"), -1);
 
+#if !GTK_CHECK_VERSION(2,10,0)
 #if USE_GNOMEPRINT
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
 #else
@@ -495,6 +488,7 @@ static GtkWidget *about_create_child_page_features(void)
 						 "bold", NULL);
 	gtk_text_buffer_insert(buffer, &iter, 
 		(gchar *)Q_("libgnomeprint|adds support for a complete print dialog\n"), -1);
+#endif
 
 #if HAVE_LIBSM
 	gtk_text_buffer_insert_pixbuf(buffer, &iter, active_pixbuf);
@@ -671,12 +665,15 @@ static void about_create(void)
 	gtk_window_set_title(GTK_WINDOW(window), _("About Claws Mail"));
 	gtk_container_set_border_width(GTK_CONTAINER(window), 8);
 	gtk_widget_set_size_request(window, -1, -1);
+	g_signal_connect(G_OBJECT(window), "size_allocate",
+			 G_CALLBACK(about_size_allocate_cb), NULL);
+	g_signal_connect(G_OBJECT(window), "size_allocate",
+			 G_CALLBACK(about_size_allocate_cb), NULL);
 	g_signal_connect(G_OBJECT(window), "delete_event",
 			 G_CALLBACK(gtk_widget_hide_on_delete), NULL);
 	g_signal_connect(G_OBJECT(window), "key_press_event",
 			 G_CALLBACK(key_pressed), NULL);
-	gtk_widget_realize(window);
-
+	
 	if (!geometry.min_width) {
 		geometry.min_width = 450;
 		geometry.min_height = 500;
@@ -684,6 +681,10 @@ static void about_create(void)
 
 	gtk_window_set_geometry_hints(GTK_WINDOW(window), NULL, &geometry,
 				      GDK_HINT_MIN_SIZE);
+	gtk_window_set_default_size(GTK_WINDOW(window), prefs_common.aboutwin_width,
+				    prefs_common.aboutwin_height);	
+	
+	gtk_widget_realize(window);
 
 	vbox1 = gtk_vbox_new(FALSE, 8);
 	gtk_container_add(GTK_CONTAINER(window), vbox1);
@@ -719,7 +720,7 @@ static void about_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox2), button, FALSE, FALSE, 0);
 #ifndef GENERIC_UMPC
 	label = gtk_label_new
-		(_("Copyright (C) 1999-2008\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
+		(_("Copyright (C) 1999-2010\nHiroyuki Yamamoto <hiro-y@kcn.ne.jp>\n"
 		 "and the Claws Mail team"));
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
@@ -784,6 +785,16 @@ static gboolean key_pressed(GtkWidget *widget, GdkEventKey *event)
 	return FALSE;
 }
 
+static void about_size_allocate_cb(GtkWidget *widget,
+				   GtkAllocation *allocation)
+{
+	cm_return_if_fail(allocation != NULL);
+
+	prefs_common.aboutwin_width = allocation->width;
+	prefs_common.aboutwin_height = allocation->height;
+}
+
+
 static gboolean about_textview_uri_clicked(GtkTextTag *tag, GObject *obj,
 					GdkEvent *event, GtkTextIter *iter,
 					GtkWidget *textview)
