@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 2001-2009 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -130,7 +130,9 @@ static struct
 #define LABEL_COLORS_ELEMS (sizeof label_colors[0] / sizeof label_colors[0][0])
 
 #define G_RETURN_VAL_IF_INVALID_COLOR(color, val) \
-	g_return_val_if_fail((color) >= 0 && (color) < LABEL_COLORS_ELEMS, (val))
+	do if ((color) < 0 || (color) >= LABEL_COLORS_ELEMS) {	\
+		return val;				    	\
+	} while(0)
 
 #define INTCOLOR_TO_GDKCOLOR(intcolor, gdkcolor) \
 	gdkcolor.red   = ((intcolor >> 16UL) & 0xFFUL) << 8UL; \
@@ -248,7 +250,7 @@ static void colorlabel_recreate_color(gint color)
 			continue;
 
 		widget = colorlabel_create_color_widget(label_colors[i][color].color);
-		g_return_if_fail(widget);
+		cm_return_if_fail(widget);
 
 		if (label_colors[i][color].widget) 
 			gtk_widget_destroy(label_colors[i][color].widget);
