@@ -321,8 +321,6 @@ MimeView *mimeview_create(MainWindow *mainwin)
     	mime_toggle = gtk_event_box_new();
 	gtk_event_box_set_visible_window(GTK_EVENT_BOX(mime_toggle), FALSE);
 
-	g_signal_connect(G_OBJECT(mime_toggle), "visibility-notify-event",
-			 G_CALLBACK(mimeview_visi_notify), mimeview);
 	g_signal_connect(G_OBJECT(mime_toggle), "motion-notify-event",
 			 G_CALLBACK(mimeview_visi_notify), mimeview);
 	g_signal_connect(G_OBJECT(mime_toggle), "leave-notify-event",
@@ -1598,8 +1596,10 @@ static gchar *mimeview_get_filename_for_part(MimeInfo *partinfo,
 	gchar *filename;
 
 	filename = g_strdup(get_part_name(partinfo));
-	if (!filename || !*filename)
+	if (!filename || !*filename) {
+		g_free(filename);
 		filename = g_strdup_printf("noname.%d", number);
+	}
 
 	if (!g_utf8_validate(filename, -1, NULL)) {
 		gchar *tmp = conv_filename_to_utf8(filename);
@@ -2217,8 +2217,6 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 	mimeview->icon_count++;
 	button = gtk_event_box_new();
 
-	g_signal_connect(G_OBJECT(button), "visibility-notify-event",
-			 G_CALLBACK(mimeview_visi_notify), mimeview);
 	g_signal_connect(G_OBJECT(button), "motion-notify-event",
 			 G_CALLBACK(mimeview_visi_notify), mimeview);
 	g_signal_connect(G_OBJECT(button), "leave-notify-event",
