@@ -243,6 +243,10 @@ static PrefParam param[] = {
 	 P_BOOL, NULL, NULL, NULL},
         {"autosave_length", "50", &prefs_common.autosave_length, P_INT,
 	 NULL, NULL, NULL},
+        {"warn_large_insert", "TRUE", &prefs_common.warn_large_insert,
+	 P_BOOL, NULL, NULL, NULL},
+        {"warn_large_insert_size", "500", &prefs_common.warn_large_insert_size,
+	 P_INT, NULL, NULL, NULL},
 
 	{"enable_aspell", "TRUE", &prefs_common.enable_aspell, P_BOOL,
 	 NULL, NULL, NULL},
@@ -1026,6 +1030,11 @@ static PrefParam param[] = {
 	{"aboutwin_height", "500", &prefs_common.aboutwin_height, P_INT,
 	 NULL, NULL, NULL},
 
+	{"addrgather_width", "450", &prefs_common.addrgather_width, P_INT,
+	 NULL, NULL, NULL},
+	{"addrgather_height", "-1", &prefs_common.addrgather_height, P_INT,
+	 NULL, NULL, NULL},
+
 	/* Hidden */
 	{"warn_dnd", "1", &prefs_common.warn_dnd, P_INT,
 	 NULL, NULL, NULL},
