@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,4 +23,11 @@
 void prefs_toolbar_init		(void);
 void prefs_toolbar_done		(void);
 
+/* parent is a MainWindow, Compose, or MessageView, depending on the ToolbarType during registration */
+typedef void (*ToolbarPluginCallback)(gpointer parent, const gchar *item_name, gpointer data);
+
+void prefs_toolbar_register_plugin_item(ToolbarType toolbar_type, const gchar *plugin_name, const gchar *item_name, ToolbarPluginCallback cb, gpointer cb_data);
+void prefs_toolbar_unregister_plugin_item(ToolbarType toolbar_type, const gchar *plugin_name, const gchar *item_name);
+void prefs_toolbar_execute_plugin_item(gpointer parent, ToolbarType toolbar_type, const gchar *id);
+
 #endif /* __PREFS_CUSTOM_TOOLBAR_H__ */ 
