@@ -593,6 +593,7 @@ static void send_progress_dialog_destroy(SendProgressDialog *dialog)
 static void send_cancel_button_cb(GtkWidget *widget, gpointer data)
 {
 	SendProgressDialog *dialog = (SendProgressDialog *)data;
+	statusbar_progress_all(0,0,0);
 
 	dialog->cancelled = TRUE;
 }
@@ -638,7 +639,7 @@ static void send_put_error(Session *session)
 		case SESSION_TIMEOUT:
 			log_msg = _("Session timed out. You may be able to "
 				    "recover by increasing the timeout value in "
-				    "Preferences/Other.");
+				    "Preferences/Other/Miscellaneous.");
 			err_msg = g_strdup(log_msg);
 			break;
 		default:
