@@ -136,6 +136,8 @@ static void toolbar_print_cb			(GtkWidget	*widget,
 
 static void toolbar_actions_execute_cb	   	(GtkWidget     	*widget,
 				  	    	 gpointer      	 data);
+static void toolbar_plugins_execute_cb      (GtkWidget      *widget,
+                             gpointer        data);
 
 
 static void toolbar_send_cb			(GtkWidget	*widget,
@@ -214,7 +216,8 @@ struct {
 	{ "A_CLAWS_ACTIONS",   	N_("Claws Mail Actions Feature")	   }, 
 	{ "A_CANCEL_INC",	N_("Cancel receiving")			   },
 	{ "A_CLOSE",		N_("Close window")			   },
-	{ "A_SEPARATOR",     	N_("Separator")				}
+	{ "A_SEPARATOR",     	N_("Separator")				},
+	{ "A_CLAWS_PLUGINS",    N_("Claws Mail Plugins")       },
 };
 
 /* struct holds configuration files and a list of
@@ -273,7 +276,7 @@ static gboolean toolbar_is_duplicate(gint action, ToolbarType source)
 {
 	GSList *cur;
 
-	if ((action == A_SEPARATOR) || (action == A_CLAWS_ACTIONS)) 
+	if ((action == A_SEPARATOR) || (action == A_CLAWS_ACTIONS) || (action == A_CLAWS_PLUGINS))
 		return FALSE;
 
 	for (cur = toolbar_config[source].item_list; cur != NULL; cur = cur->next) {
@@ -1618,6 +1621,12 @@ static void toolbar_actions_execute_cb(GtkWidget *widget, gpointer data)
 	toolbar_action_execute(widget, action_list, parent, toolbar_item->type);	
 }
 
+static void toolbar_plugins_execute_cb(GtkWidget *widget, gpointer data)
+{
+	ToolbarItem *toolbar_item = data;
+	prefs_toolbar_execute_plugin_item(toolbar_item->parent, toolbar_item->type, toolbar_item->text);
+}
+
 static MainWindow *get_mainwin(gpointer data)
 {
 	ToolbarItem *toolbar_item = (ToolbarItem*)data;
@@ -1712,7 +1721,8 @@ static void toolbar_buttons_cb(GtkWidget   *widget,
 		{ A_CHECK_SPELLING,     toolbar_check_spelling_cb       },
 #endif
 		{ A_CLAWS_ACTIONS,	toolbar_actions_execute_cb	},
-		{ A_CANCEL_INC,		toolbar_cancel_inc_cb		}
+		{ A_CANCEL_INC,		toolbar_cancel_inc_cb		},
+		{ A_CLAWS_PLUGINS,  toolbar_plugins_execute_cb  },
 	};
 
 	num_items = sizeof(callbacks)/sizeof(callbacks[0]);
@@ -2112,6 +2122,9 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,_("Cancel receiving"));
 			toolbar_data->cancel_inc_btn = item;
 			break;
+		case A_CLAWS_PLUGINS:
+			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text, toolbar_item->text);
+			break;
 		default:
 			TOOLBAR_ITEM(item,icon_wid,toolbar_item->text,
 				toolbar_ret_descr_from_val(toolbar_item->index));
@@ -2150,7 +2163,7 @@ Toolbar *toolbar_create(ToolbarType 	 type,
 	
 #ifndef MAEMO
 	gtk_container_add(GTK_CONTAINER(container), toolbar);
-	gtk_container_set_border_width(GTK_CONTAINER(container), 2);
+	gtk_container_set_border_width(GTK_CONTAINER(container), 0);
 #else
 	if ( GTK_IS_WINDOW(container) ) {
 		hildon_window_add_toolbar (HILDON_WINDOW(container), GTK_TOOLBAR(toolbar));
